handlers

package
v0.0.0-...-5186bfa Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 25, 2024 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateInstance

func CreateInstance(c *gin.Context)

func GetInstances

func GetInstances(c *gin.Context)

func GetMetadata

func GetMetadata(c *gin.Context)

Returns user (if token is valid), a list of services, and plans.

func GetUser

func GetUser(c *gin.Context)

GetUser retrieves the user information from the database based on the email stored in the context.

func SignIn

func SignIn(c *gin.Context)

SignIn handles user sign-in, validates the ID token, and creates or updates the user in the database.

Types

This section is empty.

Jump to